@@ -30,10 +30,10 @@ import os
 import simplejson
 import traceback
 import contextlib
-
+import django
 from django.conf import settings
 from django.contrib.auth.models import User, Group
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes import fields
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
 from django.core.exceptions import (
@@ -118,12 +118,11 @@ class SoftwarePackageScratch(models.Model):
 
 class NamedAttribute(models.Model):
     """
-    Model for adding generic named attributes
-    to arbitrary other model instances.
+    Model for adding named attributes to arbitrary other model instances.
 
     Example:
         class Foo(Model):
-            attributes = generic.GenericRelation(NamedAttribute)
+            attributes = fields.GenericRelation(NamedAttribute)
     """
     name = models.TextField()
 
@@ -132,7 +131,7 @@ class NamedAttribute(models.Model):
     # Content type plumbing
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField()
-    content_object = generic.GenericForeignKey('content_type', 'object_id')
+    content_object = fields.GenericForeignKey('content_type', 'object_id')
     is_manual = models.NullBooleanField(null=True)
 
     def __unicode__(self):
@@ -169,7 +168,7 @@ class HardwareDevice(models.Model):
         verbose_name=_(u"Description"),
     )
 
-    attributes = generic.GenericRelation(NamedAttribute)
+    attributes = fields.GenericRelation(NamedAttribute)
 
     def __unicode__(self):
         return self.description
@@ -1019,7 +1018,7 @@ class TestRun(models.Model):
 
     # Attributes
 
-    attributes = generic.GenericRelation(NamedAttribute)
+    attributes = fields.GenericRelation(NamedAttribute)
 
     # Tags
 
@@ -1031,7 +1030,7 @@ class TestRun(models.Model):
 
     # Attachments
 
-    attachments = generic.GenericRelation('Attachment')
+    attachments = fields.GenericRelation('Attachment')
 
     def __unicode__(self):
         return _(u"Test run {0}").format(self.analyzer_assigned_uuid)
@@ -1207,7 +1206,7 @@ class Attachment(models.Model):
     # Content type plumbing
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField()
-    content_object = generic.GenericForeignKey('content_type', 'object_id')
+    content_object = fields.GenericForeignKey('content_type', 'object_id')
 
     def __unicode__(self):
         return self.content_filename
@@ -1408,11 +1407,11 @@ class TestResult(models.Model):
 
     # Attributes
 
-    attributes = generic.GenericRelation(NamedAttribute)
+    attributes = fields.GenericRelation(NamedAttribute)
 
     # Attachments
 
-    attachments = generic.GenericRelation(Attachment)
+    attachments = fields.GenericRelation(Attachment)
 
     # Duration property
 
@@ -1451,7 +1450,6 @@ class TestResult(models.Model):
 
     class Meta:
         ordering = ['relative_index']
-        order_with_respect_to = 'test_run'
 
 
 class Tag(models.Model):
@@ -1954,6 +1952,7 @@ class ImageReport(models.Model):
         ImageReportGroup,
         default=None,
         null=True,
+        blank=True,
         on_delete=models.CASCADE)
 
     user = models.ForeignKey(
@@ -1965,6 +1964,7 @@ class ImageReport(models.Model):
         Group,
         default=None,
         null=True,
+        blank=True,
         on_delete=models.SET_NULL)
 
     description = models.TextField(blank=True, null=True)
@@ -1973,6 +1973,10 @@ class ImageReport(models.Model):
         default=False,
         verbose_name='Published')
 
+    is_archived = models.BooleanField(
+        default=False,
+        verbose_name='Archived')
+
     def __unicode__(self):
         return self.name
 
@@ -2309,7 +2313,7 @@ class ImageReportChart(models.Model):
                     "bundle_link": test_run.bundle.get_absolute_url(),
                     "alias": alias,
                     "number": str(test_run.build_number),
-                    "date": str(test_run.bundle.uploaded_on),
+                    "date": str(test_run.analyzer_assigned_date),
                     "attribute": attribute,
                     "pass": denorm.count_fail == 0,
                     "passes": denorm.count_pass,
@@ -2421,7 +2425,7 @@ class ImageReportChart(models.Model):
                 "link": test_result.get_absolute_url(),
                 "pass": test_result.result == 0,
                 "number": str(test_result.build_number),
-                "date": str(test_result.test_run.bundle.uploaded_on),
+                "date": str(test_result.test_run.analyzer_assigned_date),
                 "attribute": attribute,
                 "test_run_uuid": test_result.test_run.analyzer_assigned_uuid,
                 "bug_links": bug_links,
@@ -2496,7 +2500,7 @@ class ImageReportChart(models.Model):
                         "link": test_run.get_absolute_url(),
                         "alias": alias,
                         "number": str(test_run.build_number),
-                        "date": str(test_run.bundle.uploaded_on),
+                        "date": str(test_run.analyzer_assigned_date),
                         "pass": denorm.count_fail == 0,
                         "attr_value": value,
                         "test_run_uuid": test_run.analyzer_assigned_uuid,
