@@ -36,6 +36,11 @@ class ResultsExtension(LavaServerExtension):
     def version(self):
         return ""
 
+    @property
+    def api_class(self):
+        from lava_results_app.xmlrpc import ResultsAPI
+        return ResultsAPI
+
     @property
     def main_view_name(self):
         return "lava_results_app.views.index"
