@@ -38,10 +38,20 @@ urlpatterns = patterns(
         'query.views.query_edit', name='lava.results.query_edit'),
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+delete$',
         'query.views.query_delete', name='lava.results.query_delete'),
+    url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+export$',
+        'query.views.query_export', name='lava.results.query_export'),
+    url(r'^query/\+export-custom$', 'query.views.query_export_custom',
+        name='lava.results.query_export_custom'),
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+toggle-published$', 'query.views.query_toggle_published', name='lava.results.query_toggle_published'),
+    url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+copy$', 'query.views.query_copy'),
+    url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+refresh$', 'query.views.query_refresh', name='lava.results.query_refresh'),
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+add-condition$', 'query.views.query_add_condition', name='lava.results.query_add_condition'),
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+remove-condition$', 'query.views.query_remove_condition', name='lava.results.query_remove_condition'),
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+edit-condition$', 'query.views.query_edit_condition', name='lava.results.query_edit_condition'),
+    url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+add-group$', 'query.views.query_add_group', name='query_add_group'),
+    url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+select-group$', 'query.views.query_select_group', name='query_select_group'),
+    url(r'^query/get-query-groups$', 'query.views.query_group_list', name='query_group_list'),
+    url(r'^query/\+get-group-names$', 'query.views.get_group_names'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)$',
         'testjob', name='lava.results.testjob'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/csv$',
@@ -50,6 +60,8 @@ urlpatterns = patterns(
         'testjob_yaml', name='lava.results.testjob_yaml'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)$',
         'suite', name='lava.results.suite'),
+    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/(?P<ts>[-_a-zA-Z0-9.]+)/(?P<case>[-_a-zA-Z0-9.]+)$',
+        'testset', name='lava.results.testset'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/csv$',
         'suite_csv', name='lava.results.suite_csv'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/stream/csv$',
