@@ -42,19 +42,13 @@ class IDLinkColumn(tables.Column):
 class RestrictedIDLinkColumn(IDLinkColumn):
 
     def render(self, record, table=None):
-
-        if record.actual_device:
-            device_type = record.actual_device.device_type
-        elif record.requested_device:
-            device_type = record.requested_device.device_type
-        elif record.requested_device_type:
-            device_type = record.requested_device_type
-        else:
+        user = table.context.get('request').user
+        device_type = record.job_device_type()
+        if not device_type:
             return pklink(record)
-
-        if len(device_type.devices_visible_to(table.context.get('request').user)) == 0:
+        if len(device_type.devices_visible_to(user)) == 0:
             return "Unavailable"
-        elif record.is_accessible_by(table.context.get('request').user):
+        elif record.is_accessible_by(user):
             return pklink(record)
         else:
             return record.pk
@@ -175,9 +169,13 @@ class JobTable(LavaTable):
         elif record.requested_device:
             device_type = record.requested_device.device_type
             retval = pklink(record.requested_device)
-        else:
+        elif record.requested_device_type:
             device_type = record.requested_device_type
             retval = mark_safe('<i>%s</i>' % escape(record.requested_device_type.pk))
+        elif record.dynamic_connection:
+            return 'connection'
+        else:
+            return '-'
         if len(device_type.devices_visible_to(self.context.get('request').user)) == 0:
             return "Unavailable"
         return retval
