@@ -15,6 +15,7 @@ urlpatterns = patterns(
     url(r'^edit_worker_desc',
         'edit_worker_desc',
         name='lava.scheduler.edit_worker_desc'),
+    url(r'^activejobs$', 'active_jobs', name='lava.scheduler.job.active'),
     url(r'^alljobs$',
         'job_list',
         name='lava.scheduler.job.list'),
@@ -33,6 +34,7 @@ urlpatterns = patterns(
     url(r'^device/(?P<pk>[-_a-zA-Z0-9.]+)$',
         'device_detail',
         name='lava.scheduler.device.detail'),
+    url(r'^allworkers$', 'workers', name='lava.scheduler.workers'),
     url(r'^worker/(?P<pk>[-_a-zA-Z0-9.]+)$',
         'worker_detail',
         name='lava.scheduler.worker.detail'),
@@ -96,6 +98,21 @@ urlpatterns = patterns(
     url(r'^job/(?P<pk>[0-9]+)/log_file/plain$',
         'job_log_file_plain',
         name='lava.scheduler.job.log_file.plain'),
+    url(r'^job/(?P<pk>[0-9]+)/pipeline_incremental$',
+        'job_pipeline_incremental',
+        name='lava.scheduler.job_pipeline_incremental'),
+    url(r'^job/(?P<pk>[0-9]+)/pipeline_sections$',
+        'job_pipeline_sections',
+        name='lava.scheduler.job_pipeline_sections'),
+    url(r'^job/(?P<pk>[0-9]+)/job_status$',
+        'job_status',
+        name='lava.scheduler.job_status'),
+    url(r'^job/(?P<pk>[0-9]+)/complete_log$',
+        'job_complete_log',
+        name='lava.scheduler.job.complete_log'),
+    url(r'^job/(?P<job>[0-9]+)(/download/)(?P<log_name>[-_a-zA-Z0-9.]+)$',
+        'job_section_log',
+        name='lava.scheduler.job.section_log'),
     url(r'^job/(?P<pk>[0-9]+)/cancel$',
         'job_cancel',
         name='lava.scheduler.job.cancel'),
@@ -171,6 +188,12 @@ urlpatterns = patterns(
     url(r'^queue$',
         'queue',
         name='lava.scheduler.queue'),
+    url(r'^pipeline$',
+        'pipeline',
+        name='lava.scheduler.pipeline'),
+    url(r'^healthcheck$',
+        'healthcheck',
+        name='lava.scheduler.healthcheck'),
     url(r'^running$',
         'running',
         name='lava.scheduler.running'),
