@@ -577,6 +577,41 @@ def prepare_jinja_template(hostname, jinja_data, system_path=True, path=None):
     return env.get_template("%s.yaml" % hostname)
 
 
+def folded_logs(job, section_name, sections, summary=False, increment=False):
+    log_data = None
+    if increment:
+        latest = 0
+        section_name = ''
+        for item in sections:
+            current = int(item.values()[0])
+            log_path = os.path.join(job.output_dir, 'pipeline', item.values()[0])
+            if os.path.isdir(log_path):
+                latest = current if current > latest else latest
+                section_name = item.keys()[0] if latest == current else section_name
+        if not section_name:
+            return log_data
+    for item in sections:
+        if section_name in item:
+            log_path = os.path.join(job.output_dir, 'pipeline', item[section_name])
+            if not os.path.exists(log_path):
+                return None
+            logs = {}
+            for logfile in os.listdir(log_path):
+                filepath = os.path.join(log_path, logfile)
+                logs['filename'] = filepath
+                with open(filepath, 'r') as log_files:
+                    logs[logfile] = yaml.load(log_files)
+            log_keys = sorted(logs)
+            log_data = OrderedDict()
+            for key in log_keys:
+                summary_items = [item for item in logs[key] if 'ts' in item or 'warning' in item or 'exception' in item]
+                if summary_items and summary:
+                    log_data[key] = summary_items
+                else:
+                    log_data[key] = logs[key]
+    return log_data
+
+
 def split_multinode_yaml(submission, target_group):  # pylint: disable=too-many-branches,too-many-locals
     """
     Handles the lava-multinode protocol requirements.
