@@ -24,6 +24,9 @@ import subprocess
 import os
 
 
+# pylint: disable=superfluous-parens,too-many-locals
+
+
 def version_tag():
     """
     Parses the git status to determine if this is a git tag
@@ -67,8 +70,6 @@ def version_tag():
         # use the rev-list count to always ensure that we are building
         # a newer version to cope with date changes at month end.
         # use short git hash for reference.
-        bits = tag_name.split('.')
-        tag_month = int(bits[1])
         dev_stamp = ['git', 'rev-list', '--count', 'HEAD']
         dev_count = subprocess.check_output(dev_stamp).strip()
         dev_short = ['git', 'rev-parse', '--short', 'HEAD']
